==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrust.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property acms
 * @property files
 * @property sds
 */
public data class GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrust(
    public val acms: List<GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustAcm>,
    public val files: List<GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustFile>,
    public val sds: List<GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustSd>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrust):
            GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrust =
            GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrust(
                acms = javaType.acms().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustAcm.Companion.toKotlin(args0)
                    })
                }),
                files = javaType.files().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustFile.Companion.toKotlin(args0)
                    })
                }),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustSd.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrust.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property acms
 * @property files
 * @property sds
 */
public data class GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrust(
    public val acms: List<GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustAcm>,
    public val files: List<GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustFile>,
    public val sds: List<GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustSd>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrust): GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrust =
            GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrust(
                acms = javaType.acms().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustAcm.Companion.toKotlin(args0)
                    })
                }),
                files = javaType.files().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustFile.Companion.toKotlin(args0)
                    })
                }),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecBackendDefaultClientPolicyTlValidationTrustSd.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}
